==========================================
``psyclone.domain.lfric.kernel_interface``
==========================================

.. automodule:: psyclone.domain.lfric.kernel_interface

   .. contents::
      :local:

.. currentmodule:: psyclone.domain.lfric.kernel_interface
